@@ -4,17 +4,32 @@
   GATK -- Next-generation sequence processing.
 """
 from contextlib import closing
-import copy
 from distutils.version import LooseVersion
 import re
 import os
 import subprocess
 
+from bcbio import utils
 from bcbio.broad import picardrun
 from bcbio.pipeline import config_utils
 from bcbio.provenance import do, programs
 from bcbio.utils import curdir_tmpdir
 
+def get_default_jvm_opts(tmp_dir=None):
+    """Retrieve default JVM tuning options
+
+    Avoids issues with multiple spun up Java processes running into out of memory errors.
+    Parallel GC can use a lot of cores on big machines and primarily helps reduce task latency
+    and responsiveness which are not needed for batch jobs.
+    https://github.com/chapmanb/bcbio-nextgen/issues/532#issuecomment-50989027
+    https://wiki.csiro.au/pages/viewpage.action?pageId=545034311
+    http://stackoverflow.com/questions/9738911/javas-serial-garbage-collector-performing-far-better-than-other-garbage-collect
+    """
+    opts = ["-XX:+UseSerialGC"]
+    if tmp_dir:
+        opts.append("-Djava.io.tmpdir=%s" % tmp_dir)
+    return opts
+
 def _get_gatk_opts(config, names, tmp_dir=None, memscale=None, include_gatk=True):
     """Retrieve GATK memory specifications, moving down a list of potential specifications.
     """
@@ -23,8 +38,6 @@ def _get_gatk_opts(config, names, tmp_dir=None, memscale=None, include_gatk=True
                 "BadCigar", "--read_filter", "NotPrimaryAlignment"]
     else:
         opts = []
-    if tmp_dir:
-        opts.append("-Djava.io.tmpdir=%s" % tmp_dir)
     jvm_opts = ["-Xms750m", "-Xmx2g"]
     for n in names:
         resources = config_utils.get_resources(n, config)
@@ -33,10 +46,11 @@ def _get_gatk_opts(config, names, tmp_dir=None, memscale=None, include_gatk=True
             break
     if memscale:
         jvm_opts = config_utils.adjust_opts(jvm_opts, {"algorithm": {"memory_adjust": memscale}})
+    jvm_opts += get_default_jvm_opts(tmp_dir)
     return jvm_opts + opts
 
-def get_gatk_framework_opts(config, tmp_dir=None, memscale=None):
-    return _get_gatk_opts(config, ["gatk-framework", "gatk"], tmp_dir, memscale)
+def get_gatk_framework_opts(config, tmp_dir=None, memscale=None, include_gatk=True):
+    return _get_gatk_opts(config, ["gatk-framework", "gatk"], tmp_dir, memscale, include_gatk=include_gatk)
 
 def get_gatk_opts(config, tmp_dir=None, memscale=None, include_gatk=True):
     return _get_gatk_opts(config, ["gatk", "gatk-framework"], tmp_dir, memscale,
@@ -48,10 +62,23 @@ def get_gatk_vqsr_opts(config, tmp_dir=None, memscale=None):
 def get_picard_opts(config, memscale=None):
     return _get_gatk_opts(config, ["picard", "gatk", "gatk-framework"], memscale=memscale, include_gatk=False)
 
+def _clean_java_out(version_str):
+    """Remove extra environmental information reported in java when querying for versions.
+
+    Java will report information like _JAVA_OPTIONS environmental variables in the output.
+    """
+    out = []
+    for line in version_str.split("\n"):
+        if line.startswith("Picked up"):
+            pass
+        else:
+            out.append(line)
+    return "\n".join(out)
+
 def get_gatk_version(gatk_jar):
-    cl = ["java", "-Xms128m", "-Xmx256m", "-jar", gatk_jar, "-version"]
+    cl = ["java", "-Xms128m", "-Xmx256m"] + get_default_jvm_opts() + ["-jar", gatk_jar, "-version"]
     with closing(subprocess.Popen(cl, stdout=subprocess.PIPE, stderr=subprocess.STDOUT).stdout) as stdout:
-        out = stdout.read().strip()
+        out = _clean_java_out(stdout.read().strip())
         # versions earlier than 2.4 do not have explicit version command,
         # parse from error output from GATK
         if out.find("ERROR") >= 0:
@@ -69,7 +96,7 @@ def get_mutect_version(mutect_jar):
     """Retrieves version from input jar name since there is not an easy way to get MuTect version.
     Check mutect jar for SomaticIndelDetector, which is an Appistry feature
     """
-    cl = ["java", "-Xms128m", "-Xmx256m", "-jar", mutect_jar, "-h"]
+    cl = ["java", "-Xms128m", "-Xmx256m"] + get_default_jvm_opts() + ["-jar", mutect_jar, "-h"]
     with closing(subprocess.Popen(cl, stdout=subprocess.PIPE, stderr=subprocess.STDOUT).stdout) as stdout:
         if "SomaticIndelDetector" in stdout.read().strip():
             mutect_type = "-appistry"
@@ -165,7 +192,7 @@ class BroadRunner:
             return self._picard_version
         if os.path.isdir(self._picard_ref):
             picard_jar = self._get_jar(command)
-            cl = ["java", "-Xms64m", "-Xmx128m", "-jar", picard_jar]
+            cl = ["java", "-Xms64m", "-Xmx128m"] + get_default_jvm_opts() + ["-jar", picard_jar]
         else:
             cl = [self._picard_ref, command]
         cl += ["--version"]
@@ -193,9 +220,8 @@ class BroadRunner:
         support_nt = set()
         support_nct = set(["BaseRecalibrator"])
         gatk_jar = self._get_jar("GenomeAnalysisTK", ["GenomeAnalysisTKLite"])
-        local_args = []
         cores = self._config["algorithm"].get("num_cores", 1)
-        config = copy.deepcopy(self._config)
+        config = self._config
         if cores and int(cores) > 1:
             atype_index = params.index("-T") if params.count("-T") > 0 \
                           else params.index("--analysis_type")
@@ -205,6 +231,7 @@ class BroadRunner:
             elif prog in support_nct:
                 params.extend(["-nct", str(cores)])
                 if config["algorithm"].get("memory_adjust") is None:
+                    config = utils.deepish_copy(config)
                     config["algorithm"]["memory_adjust"] = {"direction": "increase",
                                                             "magnitude": int(cores) // 2}
         if LooseVersion(self.gatk_major_version()) > LooseVersion("1.9"):
@@ -213,25 +240,26 @@ class BroadRunner:
             params.extend(["--read_filter", "BadCigar", "--read_filter", "NotPrimaryAlignment"])
         if memscale:
             jvm_opts = get_gatk_opts(config, tmp_dir=tmp_dir, memscale=memscale, include_gatk=False)
-            local_args.append("-Djava.io.tmpdir=%s" % tmp_dir)
         else:
-            jvm_opts = config_utils.adjust_opts(self._jvm_opts, config)
+            # Decrease memory slightly from configuration to avoid memory allocation errors
+            jvm_opts = config_utils.adjust_opts(self._jvm_opts,
+                                                {"algorithm": {"memory_adjust":
+                                                               {"magnitude": 1.1, "direction": "decrease"}}})
+            jvm_opts += get_default_jvm_opts(tmp_dir)
         if "keyfile" in self._gatk_resources:
             params = ["-et", "NO_ET", "-K", self._gatk_resources["keyfile"]] + params
-        return ["java"] + jvm_opts + local_args + \
-          ["-jar", gatk_jar] + [str(x) for x in params]
+        return ["java"] + jvm_opts + ["-jar", gatk_jar] + [str(x) for x in params]
 
     def cl_mutect(self, params, tmp_dir):
-
-        """Define parameters to run the mutect paired algorithm."""
-
+        """Define parameters to run the mutect paired algorithm.
+        """
         gatk_jar = self._get_jar("muTect")
-        local_args = []
-        config = copy.deepcopy(self._config)
-
-        local_args.append("-Djava.io.tmpdir=%s" % tmp_dir)
-        return ["java"] + config_utils.adjust_opts(self._jvm_opts, config) + local_args + \
-          ["-jar", gatk_jar] + [str(x) for x in params]
+        # Decrease memory slightly from configuration to avoid memory allocation errors
+        jvm_opts = config_utils.adjust_opts(self._jvm_opts,
+                                            {"algorithm": {"memory_adjust":
+                                                           {"magnitude": 1.1, "direction": "decrease"}}})
+        return ["java"] + jvm_opts + get_default_jvm_opts(tmp_dir) + \
+               ["-jar", gatk_jar] + [str(x) for x in params]
 
     def run_gatk(self, params, tmp_dir=None, log_error=True, memory_retry=False,
                  data=None, region=None, memscale=None):
@@ -322,7 +350,7 @@ class BroadRunner:
             jvm_opts = self._jvm_opts
         if os.path.isdir(self._picard_ref):
             dist_file = self._get_jar(command)
-            return ["java"] + jvm_opts + ["-jar", dist_file]
+            return ["java"] + jvm_opts + get_default_jvm_opts() + ["-jar", dist_file]
         else:
             # XXX Cannot currently set JVM opts with picard-tools script
             return [self._picard_ref, command]
