@@ -62,6 +62,10 @@ def postprocess_variants(*args):
 def pipeline_summary(*args):
     return qcsummary.pipeline_summary(*args)
 
+@utils.map_wrap
+def qsignature_summary(*args):
+    return qcsummary.qsignature_summary(*args)
+
 @utils.map_wrap
 def generate_transcript_counts(*args):
     return rnaseq.generate_transcript_counts(*args)
