@@ -23,6 +23,7 @@ from bcbio.log import logger
 from bcbio.provenance import do
 from bcbio import bam
 from bcbio import broad
+import bcbio.pipeline.datadict as dd
 
 
 _out_fnames = ["accepted_hits.sam", "junctions.bed",
@@ -46,7 +47,7 @@ def _set_transcriptome_option(options, data, ref_file):
         options["transcriptome-index"] = os.path.splitext(transcriptome_index)[0]
         return options
 
-    gtf_file = data["genome_resources"]["rnaseq"].get("transcripts")
+    gtf_file = dd.get_gtf_file(data)
     if gtf_file:
         options["GTF"] = gtf_file
         return options
@@ -159,6 +160,7 @@ def tophat_align(fastq_file, pair_file, ref_file, out_base, align_dir, data,
     # set the contig order to match the reference file so GATK works
     fixed = picard.run_fn("picard_reorder", out_file, data["sam_ref"],
                           os.path.splitext(out_file)[0] + ".picard.bam")
+    fixed = fix_insert_size(fixed, config)
     if not file_exists(final_out):
         symlink_plus(fixed, final_out)
     return final_out
@@ -366,3 +368,28 @@ def _ref_version(ref_file):
     raise ValueError("Cannot detect which reference version %s is. "
                      "Should end in either .ebwt (bowtie) or .bt2 "
                      "(bowtie2)." % (ref_file))
+
+def fix_insert_size(in_bam, config):
+    """
+    Tophat sets PI in the RG to be the inner distance size, but the SAM spec
+    states should be the insert size. This fixes the RG in the alignment
+    file generated by Tophat header to match the spec
+    """
+    fixed_file = os.path.splitext(in_bam)[0] + ".pi_fixed.bam"
+    if file_exists(fixed_file):
+        return fixed_file
+    header_file = os.path.splitext(in_bam)[0] + ".header.sam"
+    read_length = bam.estimate_read_length(in_bam)
+    bam_handle= bam.open_samfile(in_bam)
+    header = bam_handle.header.copy()
+    rg_dict = header['RG'][0]
+    PI = int(rg_dict.get('PI'))
+    PI = PI + 2*read_length
+    rg_dict['PI'] = PI
+    header['RG'][0] = rg_dict
+    with pysam.Samfile(header_file, "wb", header=header) as out_handle:
+        with bam.open_samfile(in_bam) as in_handle:
+            for record in in_handle:
+                out_handle.write(record)
+    shutil.move(header_file, fixed_file)
+    return fixed_file
