@@ -237,14 +237,6 @@ def get_jar(base_name, dname):
 
 # ## Retrieval and update to configuration from arguments
 
-def _dictdissoc(orig, k):
-    """Imitates immutability: create a new dictionary with the key dropped.
-    """
-    v = orig.pop(k, None)
-    new = copy.deepcopy(orig)
-    orig[k] = v
-    return new
-
 def is_std_config_arg(x):
     return isinstance(x, dict) and "algorithm" in x and "resources" in x and not "files" in x
 
@@ -283,7 +275,8 @@ def add_cores_to_config(args, cores_per_job, parallel=None):
     def _update_cores(config):
         config["algorithm"]["num_cores"] = int(cores_per_job)
         if parallel:
-            config["parallel"] = _dictdissoc(parallel, "view")
+            parallel.pop("view", None)
+            config["parallel"] = parallel
         return config
     return _update_config(args, _update_cores)
 
@@ -299,14 +292,14 @@ def _update_config(args, update_fn):
     if new_i is None:
         raise ValueError("Could not find configuration in args: %s" % str(args))
 
-    new_arg = copy.deepcopy(args[new_i])
+    new_arg = args[new_i]
     if is_nested_config_arg(new_arg):
-        new_arg["config"] = update_fn(new_arg["config"])
+        new_arg["config"] = update_fn(copy.deepcopy(new_arg["config"]))
     elif is_std_config_arg(new_arg):
-        new_arg = update_fn(new_arg)
+        new_arg = update_fn(copy.deepcopy(new_arg))
     elif isinstance(arg, (list, tuple)) and is_nested_config_arg(new_arg[0]):
         new_arg_first = new_arg[0]
-        new_arg_first["config"] = update_fn(new_arg_first["config"])
+        new_arg_first["config"] = update_fn(copy.deepcopy(new_arg_first["config"]))
         new_arg = [new_arg_first] + new_arg[1:]
     else:
         raise ValueError("Unexpected configuration dictionary: %s" % new_arg)
@@ -314,7 +307,7 @@ def _update_config(args, update_fn):
     args[new_i] = new_arg
     return args
 
-def adjust_memory(val, magnitude, direction="increase"):
+def adjust_memory(val, magnitude, direction="increase", out_modifier=""):
     """Adjust memory based on number of cores utilized.
     """
     modifier = val[-1:]
@@ -328,13 +321,19 @@ def adjust_memory(val, magnitude, direction="increase"):
                 modifier = "M" + modifier[1:]
             else:
                 raise ValueError("Unexpected decrease in memory: %s by %s" % (val, magnitude))
-        amount = new_amount
+        amount = int(new_amount)
     elif direction == "increase":
         # for increases with multiple cores, leave small percentage of
         # memory for system to maintain process running resource and
         # avoid OOM killers
         adjuster = 0.91
         amount = int(math.ceil(amount * (adjuster * magnitude)))
+    if out_modifier.upper().startswith("G") and modifier.upper().startswith("M"):
+        modifier = out_modifier
+        amount = int(math.floor(amount / 1024.0))
+    if out_modifier.upper().startswith("M") and modifier.upper().startswith("G"):
+        modifier = out_modifier
+        modifier = int(amount * 1024)
     return "{amount}{modifier}".format(amount=amount, modifier=modifier)
 
 def adjust_opts(in_opts, config):
@@ -346,7 +345,7 @@ def adjust_opts(in_opts, config):
     memory_adjust = config["algorithm"].get("memory_adjust", {})
     out_opts = []
     for opt in in_opts:
-        if opt.startswith(("-Xmx", "-Xms")):
+        if opt.startswith("-Xmx") or (opt.startswith("-Xms") and memory_adjust.get("direction") == "decrease"):
             arg = opt[:4]
             opt = "{arg}{val}".format(arg=arg,
                                       val=adjust_memory(opt[4:],
