@@ -1,6 +1,7 @@
 """Quality control and summary metrics for next-gen alignments and analysis.
 """
 import collections
+import contextlib
 import csv
 import os
 import shutil
@@ -9,14 +10,16 @@ import subprocess
 import lxml.html
 import yaml
 from datetime import datetime
-
 # allow graceful during upgrades
 try:
     import matplotlib
-    matplotlib.use('Agg')
+    matplotlib.use('Agg', force=True)
     import matplotlib.pyplot as plt
+    plt.ioff()
 except ImportError:
     plt = None
+import pysam
+import toolz as tz
 
 from bcbio import bam, utils
 from bcbio.distributed.transaction import file_transaction
@@ -25,25 +28,30 @@ from bcbio.pipeline import config_utils, run_info
 from bcbio.install import _get_data_dir
 from bcbio.provenance import do
 import bcbio.rnaseq.qc
-from bcbio.variation.realign import has_aligned_reads
 from bcbio.rnaseq.coverage import plot_gene_coverage
+import bcbio.pipeline.datadict as dd
 
 # ## High level functions to generate summary
 
+
 def generate_parallel(samples, run_parallel):
     """Provide parallel preparation of summary information for alignment and variant calling.
     """
     sum_samples = run_parallel("pipeline_summary", samples)
-    summary_file = write_project_summary(sum_samples)
+    qsign_info = run_parallel("qsignature_summary", [sum_samples])
+    summary_file = write_project_summary(sum_samples, qsign_info)
     samples = []
     for data in sum_samples:
         if "summary" not in data[0]:
             data[0]["summary"] = {}
         data[0]["summary"]["project"] = summary_file
+        if qsign_info:
+            data[0]["summary"]["mixup_check"] = qsign_info[0]["out_dir"]
         samples.append(data)
     samples = _add_researcher_summary(samples, summary_file)
     return samples
 
+
 def pipeline_summary(data):
     """Provide summary information on processing sample.
     """
@@ -53,6 +61,7 @@ def pipeline_summary(data):
         data["summary"] = _run_qc_tools(work_bam, data)
     return [[data]]
 
+
 def prep_pdf(qc_dir, config):
     """Create PDF from HTML summary outputs in QC directory.
 
@@ -77,8 +86,14 @@ def prep_pdf(qc_dir, config):
             do.run(cmd, "Convert QC HTML to PDF")
         return out_file
 
+
 def _run_qc_tools(bam_file, data):
     """Run a set of third party quality control tools, returning QC directory and metrics.
+
+        :param bam_file: alignments in bam format
+        :param data: dict with all configuration information
+
+        :returns: dict with output of different tools
     """
     metrics = {}
     to_run = [("fastqc", _run_fastqc)]
@@ -90,6 +105,8 @@ def _run_qc_tools(bam_file, data):
         to_run.append(["bamtools", _run_bamtools_stats])
     else:
         to_run += [("bamtools", _run_bamtools_stats), ("gemini", _run_gemini_stats)]
+    if data["analysis"].lower().startswith(("standard", "variant2")):
+        to_run.append(["qsignature", _run_qsignature_generator])
     qc_dir = utils.safe_makedir(os.path.join(data["dirs"]["work"], "qc", data["description"]))
     metrics = {}
     for program_name, qc_fn in to_run:
@@ -97,7 +114,9 @@ def _run_qc_tools(bam_file, data):
         cur_metrics = qc_fn(bam_file, data, cur_qc_dir)
         metrics.update(cur_metrics)
     ratio = bam.get_aligned_reads(bam_file, data)
-    if ratio < 0.60 and data['config']["algorithm"].get("kraken", False) and data["analysis"].lower() == "rna-seq":
+    if (ratio < 0.60 and data['config']["algorithm"].get("kraken", False) and
+          (data["analysis"].lower().startswith("rna-seq") or
+           data["analysis"].lower().startswith("standard"))):
         cur_metrics = _run_kraken(data, ratio)
         metrics.update(cur_metrics)
     metrics["Name"] = data["name"][-1]
@@ -109,7 +128,8 @@ def _run_qc_tools(bam_file, data):
 
 # ## Generate project level QC summary for quickly assessing large projects
 
-def write_project_summary(samples):
+
+def write_project_summary(samples, qsign_info=None):
     """Write project summary information on the provided samples.
     write out dirs, genome resources,
 
@@ -127,6 +147,11 @@ def write_project_summary(samples):
         if test_run:
             yaml.safe_dump({"test_run": True}, out_handle, default_flow_style=False,
                            allow_unicode=False)
+        if qsign_info:
+            qsign_out = utils.deepish_copy(qsign_info[0])
+            qsign_out.pop("out_dir", None)
+            yaml.safe_dump({"qsignature": qsign_out}, out_handle, default_flow_style=False,
+                           allow_unicode=False)
         yaml.safe_dump({"upload": upload_dir}, out_handle,
                        default_flow_style=False, allow_unicode=False)
         yaml.safe_dump({"bcbio_system": samples[0][0]["config"].get("bcbio_system", "")}, out_handle,
@@ -148,6 +173,7 @@ def _other_pipeline_samples(summary_file, cur_samples):
                     out.append(s)
     return out
 
+
 def _save_fields(sample):
     to_save = ["dirs", "genome_resources", "genome_build", "sam_ref", "metadata",
                "description"]
@@ -166,6 +192,7 @@ def _save_fields(sample):
                 saved["summary"]["metrics"]["Disambiguated ambiguous reads"] = disambigStats[2]
     return saved
 
+
 def _parse_disambiguate(disambiguatestatsfilename):
     """Parse disambiguation stats from given file.
     """
@@ -200,6 +227,7 @@ def _add_researcher_summary(samples, summary_yaml):
         out.append([data])
     return out
 
+
 def _summary_csv_by_researcher(summary_yaml, researcher, descrs, data):
     """Generate a CSV file with summary information for a researcher on this project.
     """
@@ -259,52 +287,57 @@ def _run_gene_coverage(bam_file, data, out_dir):
     return {"gene_coverage": out_file}
 
 
-
-def _run_kraken(data,ratio):
+def _run_kraken(data, ratio):
     """Run kraken, generating report in specified directory and parsing metrics.
        Using only first paired reads.
     """
-    logger.info("Number of aligned reads < than 0.60 in %s: %s" % (str(data["name"]),ratio))
+    logger.info("Number of aligned reads < than 0.60 in %s: %s" % (str(data["name"]), ratio))
     logger.info("Running kraken to determine contaminant: %s" % str(data["name"]))
     qc_dir = utils.safe_makedir(os.path.join(data["dirs"]["work"], "qc", data["description"]))
     kraken_out = os.path.join(qc_dir, "kraken")
-    stats = out = out_stats = None
-    db = data['config']["algorithm"]["kraken"] 
+    out = out_stats = None
+    db = data['config']["algorithm"]["kraken"]
     if db == "minikraken":
-        db = os.path.join(_get_data_dir(),"genome","kraken","minikraken")
+        db = os.path.join(_get_data_dir(), "genomes", "kraken", "minikraken")
     else:
         if not os.path.exists(db):
             logger.info("kraken: no database found %s, skipping" % db)
-            return {"kraken_report" : "null"}
-    if not os.path.exists(os.path.join(kraken_out,"kraken_out")):
+            return {"kraken_report": "null"}
+    if not os.path.exists(os.path.join(kraken_out, "kraken_out")):
         work_dir = os.path.dirname(kraken_out)
         utils.safe_makedir(work_dir)
         num_cores = data["config"]["algorithm"].get("num_cores", 1)
-        files = data["files"]        
+        files = data["files"]
+        if files[0].endswith("bam"):
+            logger.info("kraken: need fasta files as input")
+            return {"kraken_report": "null"}
         with utils.curdir_tmpdir(data, work_dir) as tx_tmp_dir:
             with utils.chdir(tx_tmp_dir):
-                out = os.path.join(tx_tmp_dir,"kraken_out")
-                out_stats = os.path.join(tx_tmp_dir,"kraken_stats")
-                cl = (" ").join([config_utils.get_program("kraken", data["config"]),
-                      "--db",db,"--quick",
-                      "--preload","--min-hits","2","--threads",str(num_cores), 
-                      "--out", out, files[0]," 2>",out_stats])
-                do.run(cl,"kraken: %s" % data["name"][-1])
+                out = os.path.join(tx_tmp_dir, "kraken_out")
+                out_stats = os.path.join(tx_tmp_dir, "kraken_stats")
+                cl = (" ").join(
+                    [config_utils.get_program("kraken", data["config"]),
+                        "--db", db, "--quick",
+                        "--preload", "--min-hits", "2",
+                        "--threads", str(num_cores),
+                        "--out", out, files[0], " 2>", out_stats])
+                do.run(cl, "kraken: %s" % data["name"][-1])
                 if os.path.exists(kraken_out):
                     shutil.rmtree(kraken_out)
                 shutil.move(tx_tmp_dir, kraken_out)
-    metrics = _parse_kraken_output(kraken_out,db,data)
+    metrics = _parse_kraken_output(kraken_out, db, data)
     return metrics
 
+
 def _parse_kraken_output(out_dir, db, data):
-    """Parse kraken stat info comming from stderr, 
+    """Parse kraken stat info comming from stderr,
        generating report with kraken-report
     """
-    in_file = os.path.join(out_dir,"kraken_out")
-    stat_file = os.path.join(out_dir,"kraken_stats")
+    in_file = os.path.join(out_dir, "kraken_out")
+    stat_file = os.path.join(out_dir, "kraken_stats")
     out_file = os.path.join(out_dir, "kraken_summary")
     classify = unclassify = None
-    with open(stat_file,'r') as handle:
+    with open(stat_file, 'r') as handle:
         for line in handle:
             if line.find(" classified") > -1:
                 classify = line[line.find("(")+1:line.find(")")]
@@ -313,9 +346,10 @@ def _parse_kraken_output(out_dir, db, data):
     if os.path.getsize(in_file)>0:
         with file_transaction(out_file) as tx_out_file:
             cl = (" ").join([config_utils.get_program("kraken-report", data["config"]),
-                          "--db",db,in_file,">",tx_out_file])
+                          "--db", db, in_file, ">", tx_out_file])
             do.run(cl, "kraken report: %s" % data["name"][-1])
-    return {"kraken_report" : out_file,"kraken_clas": classify,"kraken_unclas": unclassify}
+    return {"kraken_report" : out_file, "kraken_clas": classify, "kraken_unclas": unclassify}
+
 
 def _run_fastqc(bam_file, data, fastqc_out):
     """Run fastqc, generating report in specified directory and parsing metrics.
@@ -359,6 +393,7 @@ def _run_fastqc(bam_file, data, fastqc_out):
     stats = parser.get_fastqc_summary()
     return stats
 
+
 def _run_complexity(bam_file, data, out_dir):
     try:
         import pandas as pd
@@ -379,7 +414,6 @@ def _run_complexity(bam_file, data, out_dir):
 
     print "file saved as", out_file
     print "out_dir is", out_dir
-
     return bcbio.rnaseq.qc.estimate_library_complexity(df)
 
 
@@ -529,7 +563,7 @@ def _run_gemini_stats(bam_file, data, out_dir):
     """Retrieve high level variant statistics from Gemini.
     """
     out = {}
-    gemini_db = (data.get("variants", [{}])[0].get("population", {}).get("db") 
+    gemini_db = (data.get("variants", [{}])[0].get("population", {}).get("db")
                  if data.get("variants") else None)
     if gemini_db:
         gemini_stat_file = "%s-stats.yaml" % os.path.splitext(gemini_db)[0]
@@ -558,3 +592,163 @@ def _run_gemini_stats(bam_file, data, out_dir):
             with open(gemini_stat_file) as in_handle:
                 out = yaml.safe_load(in_handle)
     return out
+
+
+## qsignature
+
+def _run_qsignature_generator(bam_file, data, out_dir):
+    """ Run SignatureGenerator to create normalize vcf that later will be input of qsignature_summary
+
+    :param bam_file: (str) path of the bam_file
+    :param data: (list) list containing the all the dictionary
+                     for this sample
+    :param out_dir: (str) path of the output
+
+    :returns: (dict) dict with the normalize vcf file
+    """
+    position = dd.get_qsig_file(data)
+    mixup_check = dd.get_mixup_check(data)
+    if position and mixup_check and mixup_check.startswith("qsignature"):
+        jvm_opts = "-Xms750m -Xmx2g"
+        limit_reads = 20000000
+        if mixup_check == "qsignature_full":
+            slice_bam = bam_file
+            jvm_opts = "-Xms750m -Xmx8g"
+            limit_reads = 100000000
+        else:
+            slice_bam = _slice_chr22(bam_file, data)
+        qsig = config_utils.get_program("qsignature", data["config"])
+        if not qsig:
+            return {}
+        utils.safe_makedir(out_dir)
+        out_name = os.path.basename(slice_bam).replace("bam", "qsig.vcf")
+        out_file = os.path.join(out_dir, out_name)
+        log_file = os.path.join(out_dir, "qsig.log")
+        cores = dd.get_cores(data)
+        base_cmd = ("{qsig} {jvm_opts} "
+                    "org.qcmg.sig.SignatureGenerator "
+                    "--noOfThreads {cores} "
+                    "-log {log_file} -i {position} "
+                    "-i {down_file} ")
+        if not os.path.exists(out_file):
+            down_file = bam.downsample(slice_bam, data, limit_reads)
+            if not down_file:
+                down_file = slice_bam
+            file_qsign_out = "{0}.qsig.vcf".format(down_file)
+            do.run(base_cmd.format(**locals()), "qsignature vcf generation: %s" % data["name"][-1])
+            if os.path.exists(file_qsign_out):
+                with file_transaction(out_file) as file_txt_out:
+                    shutil.move(file_qsign_out, file_txt_out)
+            else:
+                raise IOError("File doesn't exist %s" % file_qsign_out)
+        return {'qsig_vcf': out_file}
+    else:
+        logger.info("There is no qsignature for this species: %s"
+                    % tz.get_in(['genome_build'], data))
+        return {}
+
+
+def qsignature_summary(*samples):
+    """Run SignatureCompareRelatedSimple module from qsignature tool.
+
+    Creates a matrix of pairwise comparison among samples. The
+    function will not run if the output exists
+
+    :param samples: list with only one element containing all samples information
+    :returns: (dict) with the path of the output to be joined to summary
+    """
+    warnings, similar = [], []
+    qsig = config_utils.get_program("qsignature", samples[0][0]["config"])
+    if not qsig:
+        return [[]]
+    jvm_opts = "-Xms750m -Xmx8g"
+    work_dir = samples[0][0]["dirs"]["work"]
+    count = 0
+    for data in samples:
+        data = data[0]
+        vcf = tz.get_in(["summary", "metrics", "qsig_vcf"], data)
+        if vcf:
+            count += 1
+            vcf_name = os.path.basename(vcf)
+            out_dir = utils.safe_makedir(os.path.join(work_dir, "qsignature"))
+            if not os.path.lexists(os.path.join(out_dir, vcf_name)):
+                os.symlink(vcf, os.path.join(out_dir, vcf_name))
+    if count > 0:
+        qc_out_dir = utils.safe_makedir(os.path.join(work_dir, "qc", "qsignature"))
+        out_file = os.path.join(qc_out_dir, "qsignature.xml")
+        out_ma_file = os.path.join(qc_out_dir, "qsignature.ma")
+        out_warn_file = os.path.join(qc_out_dir, "qsignature.warnings")
+        log = os.path.join(work_dir, "qsignature", "qsig-summary.log")
+        if not os.path.exists(out_file):
+            with file_transaction(out_file) as file_txt_out:
+                base_cmd = ("{qsig} {jvm_opts} "
+                            "org.qcmg.sig.SignatureCompareRelatedSimple "
+                            "-log {log} -dir {out_dir} "
+                            "-o {file_txt_out} ")
+                do.run(base_cmd.format(**locals()), "qsignature score calculation")
+        warnings, similar = _parse_qsignature_output(out_file, out_ma_file, out_warn_file)
+        return [{'total samples': count,
+                 'similar samples': len(similar),
+                 'warnings samples': list(warnings),
+                 'out_dir': qc_out_dir}]
+    else:
+        return []
+
+
+def _parse_qsignature_output(in_file, out_file, warning_file):
+    """ Parse xml file produced by qsignature
+
+    :param in_file: (str) with the path to the xml file
+    :param out_file: (str) with the path to output file
+    :param warning_file: (str) with the path to warning file
+
+    :returns: (list) with samples that could be duplicated
+
+    """
+    name = {}
+    warnings = set()
+    similar = set()
+    with open(in_file, 'r') as in_handle:
+        with file_transaction(out_file) as out_tx_file:
+            with file_transaction(warning_file) as warn_tx_file:
+                with open(out_tx_file, 'w') as out_handle:
+                    with open(warn_tx_file, 'w') as warn_handle:
+                        ET = lxml.etree.parse(in_handle)
+                        for i in list(ET.iter('file')):
+                            name[i.attrib['id']] = os.path.basename(i.attrib['name']).replace(".bam.qsig.vcf", "")
+                        for i in list(ET.iter('comparison')):
+                            out_handle.write("%s\t%s\t%s\n" %
+                            (name[i.attrib['file1']], name[i.attrib['file2']], i.attrib['score']))
+                            if float(i.attrib['score']) < 0.1:
+                                logger.info('qsignature WARNING: risk of duplicated samples:%s' %
+                                    (' '.join([name[i.attrib['file1']], name[i.attrib['file2']]])))
+                                warn_handle.write('qsignature WARNING: risk of duplicated samples:%s\n' %
+                                    (' '.join([name[i.attrib['file1']], name[i.attrib['file2']]])))
+                                warnings.add(name[i.attrib['file1']])
+                                warnings.add(name[i.attrib['file2']])
+                            elif float(i.attrib['score']) < 0.18:
+                                logger.info('qsignature: read similar samples:%s' %
+                                    (' '.join([name[i.attrib['file1']], name[i.attrib['file2']]])))
+                                warn_handle.write('qsignature NOTE: similar samples:%s\n' %
+                                    (' '.join([name[i.attrib['file1']], name[i.attrib['file2']]])))
+                                similar.add(name[i.attrib['file1']])
+                                similar.add(name[i.attrib['file2']])
+    return warnings, similar
+
+def _slice_chr22(in_bam, data):
+    """
+    return only one BAM file with only chromosome 22
+    """
+    sambamba = config_utils.get_program("sambamba", data["config"])
+    out_file = "%s-chr%s" % os.path.splitext(in_bam)
+    if not utils.file_exists(out_file):
+        bam.index(in_bam, data['config'])
+        with contextlib.closing(pysam.Samfile(in_bam, "rb")) as bamfile:
+            bam_contigs = [c["SN"] for c in bamfile.header["SQ"]]
+        chromosome = "22"
+        if "chr22" in bam_contigs:
+            chromosome = "chr22"
+        with file_transaction(out_file) as tx_out_file:
+            cmd = ("{sambamba} slice -o {tx_out_file} {in_bam} {chromosome}").format(**locals())
+            out = subprocess.check_output(cmd, shell=True)
+    return out_file
