@@ -18,11 +18,10 @@ from bcbio.illumina import flowcell
 from bcbio.pipeline import alignment, config_utils, genome
 from bcbio.variation import effects, genotype, population
 from bcbio.variation.cortex import get_sample_name
-from bcbio.bam.fastq import open_fastq, is_fastq
-
+from bcbio.bam.fastq import open_fastq
 
 ALGORITHM_NOPATH_KEYS = ["variantcaller", "realign", "recalibrate",
-                         "phasing", "svcaller", "jointcaller", "tools_off"]
+                         "phasing", "svcaller", "jointcaller", "tools_off", "mixup_check"]
 
 def organize(dirs, config, run_info_yaml):
     """Organize run information from a passed YAML file or the Galaxy API.
@@ -79,6 +78,17 @@ def add_reference_resources(data):
 
 # ## Sample and BAM read group naming
 
+
+def _clean_metadata(data):
+    batches = tz.get_in(("metadata", "batch"), data)
+    if batches:
+        if isinstance(batches, (list, tuple)):
+            batches = [str(x) for x in batches]
+        else:
+            batches = str(batches)
+        data["metadata"]["batch"] = batches
+    return data
+
 def _clean_characters(x):
     """Clean problem characters in sample lane or descriptions.
     """
@@ -168,7 +178,7 @@ ALGORITHM_KEYS = set(["platform", "aligner", "bam_clean", "bam_sort",
                       "nomap_split_targets", "ensemble", "background",
                       "disambiguate", "strandedness", "fusion_mode", "min_read_length",
                       "coverage_depth_min", "coverage_depth_max", "min_allele_fraction", "remove_lcr",
-                      "archive", "tools_off", "assemble_transcripts"] +
+                      "archive", "tools_off", "assemble_transcripts", "mixup_check"] +
                      # back compatibility
                       ["coverage_depth"])
 
@@ -236,7 +246,12 @@ def _check_quality_format(items):
     fastq_extensions = ["fq.gz", "fastq.gz", ".fastq" ".fq"]
 
     for item in items:
-        specified_format = item["algorithm"].get("quality_format", "").lower()
+        specified_format = item["algorithm"].get("quality_format", "standard").lower()
+        if specified_format not in SAMPLE_FORMAT.values():
+            raise ValueError("Quality format specified in the YAML file"
+                             "is not supported. Supported values are %s."
+                             % (SAMPLE_FORMAT.values()))
+
         fastq_file = next((file for file in item.get('files', []) if
                            any([ext for ext in fastq_extensions if ext in file])), None)
 
@@ -298,6 +313,8 @@ def _file_to_abs(x, dnames):
     """
     if x is None or os.path.isabs(x):
         return x
+    elif isinstance(x, basestring) and x.lower().startswith(utils.SUPPORTED_REMOTES):
+        return x
     elif isinstance(x, basestring) and x.lower() == "none":
         return None
     else:
@@ -389,9 +406,11 @@ def _run_info_from_yaml(fc_dir, run_info_yaml, config):
         item["algorithm"] = _replace_global_vars(item["algorithm"], global_vars)
         item["algorithm"] = genome.abs_file_paths(item["algorithm"],
                                                   ignore_keys=ALGORITHM_NOPATH_KEYS)
+        item["genome_build"] = str(item.get("genome_build", ""))
         item["algorithm"] = _add_algorithm_defaults(item["algorithm"])
         item["rgnames"] = prep_rg_names(item, config, fc_name, fc_date)
         item["test_run"] = global_config.get("test_run", False)
+        item = _clean_metadata(item)
         run_details.append(item)
     _check_sample_config(run_details, run_info_yaml)
     return run_details
