@@ -11,7 +11,7 @@ import toolz as tz
 from bcbio import utils, bam, broad
 from bcbio.log import logger
 from bcbio.pipeline.merge import merge_bam_files
-from bcbio.bam import callable, fastq
+from bcbio.bam import fastq, callable
 from bcbio.bam.trim import trim_adapters
 from bcbio.ngsalign import postalign
 from bcbio.pipeline.fastq import get_fastq_files
@@ -19,6 +19,7 @@ from bcbio.pipeline.alignment import align_to_sort_bam
 from bcbio.pipeline import cleanbam
 from bcbio.variation import bedutils, recalibrate
 from bcbio.variation import multi as vmulti
+import bcbio.pipeline.datadict as dd
 
 def prepare_sample(data):
     """Prepare a sample to be run, potentially converting from BAM to
@@ -50,10 +51,13 @@ def trim_sample(data):
         logger.info("Skipping trimming of %s." % (", ".join(to_trim)))
         return [[data]]
 
+    out_dir = os.path.join(dd.get_work_dir(data), "trimmed")
+    utils.safe_makedir(out_dir)
+
     if trim_reads == "read_through":
         logger.info("Trimming low quality ends and read through adapter "
                     "sequence from %s." % (", ".join(to_trim)))
-        out_files = trim_adapters(to_trim, dirs, config)
+        out_files = trim_adapters(to_trim, out_dir, config)
     data["files"] = out_files
     return [[data]]
 
@@ -95,7 +99,7 @@ def process_alignment(data):
         fastq1, fastq2 = data["files"][0], None
     config = data["config"]
     aligner = config["algorithm"].get("aligner", None)
-    if fastq1 and os.path.exists(fastq1) and aligner:
+    if fastq1 and utils.file_exists_or_remote(fastq1) and aligner:
         logger.info("Aligning lane %s with %s aligner" % (data["rgnames"]["lane"], aligner))
         data = align_to_sort_bam(fastq1, fastq2, aligner, data)
         data = _add_supplemental_bams(data)
@@ -107,7 +111,7 @@ def process_alignment(data):
                 raise ValueError("Cannot specify `bam_clean: picard` with `bam_sort` other than coordinate: %s"
                                  % sort_method)
             out_bam = cleanbam.picard_prep(fastq1, data["rgnames"], data["sam_ref"], data["dirs"],
-                                           config)
+                                           data)
         elif sort_method:
             runner = broad.runner_from_config(config)
             out_file = os.path.join(data["dirs"]["work"], "{}-sort.bam".format(
@@ -119,7 +123,7 @@ def process_alignment(data):
         bam.check_header(out_bam, data["rgnames"], data["sam_ref"], data["config"])
         dedup_bam = postalign.dedup_bam(out_bam, data)
         data["work_bam"] = dedup_bam
-    elif fastq1 and os.path.exists(fastq1) and fastq1.endswith(".cram"):
+    elif fastq1 and utils.file_exists_or_remote(fastq1) and fastq1.endswith(".cram"):
         data["work_bam"] = fastq1
     elif fastq1 is None and "vrn_file" in data:
         data["config"]["algorithm"]["variantcaller"] = False
@@ -134,7 +138,7 @@ def postprocess_alignment(data):
     Cleans input BED files to avoid issues with overlapping input segments.
     """
     data = bedutils.clean_inputs(data)
-    if vmulti.bam_needs_processing(data):
+    if vmulti.bam_needs_processing(data) and data["work_bam"].endswith(".bam"):
         callable_region_bed, nblock_bed, callable_bed = \
             callable.block_regions(data["work_bam"], data["sam_ref"], data["config"])
         data["regions"] = {"nblock": nblock_bed, "callable": callable_bed}
