@@ -1,8 +1,9 @@
 """Pipeline functionality shared amongst multiple analysis types.
 """
 import os
-from contextlib import closing
+from contextlib import closing, contextmanager
 import functools
+import tempfile
 
 try:
     import pybedtools
@@ -149,6 +150,17 @@ def remove_lcr_regions(orig_bed, items):
             orig_bed = nolcr_bed
     return orig_bed
 
+@contextmanager
+def bedtools_tmpdir(data):
+    with utils.curdir_tmpdir(data) as tmpdir:
+        orig_tmpdir = tempfile.gettempdir()
+        pybedtools.set_tempdir(tmpdir)
+        yield
+        if orig_tmpdir and os.path.exists(orig_tmpdir):
+            pybedtools.set_tempdir(orig_tmpdir)
+        else:
+            tempfile.tempdir = None
+
 def subtract_low_complexity(f):
     """Remove low complexity regions from callable regions if available.
     """
