@@ -16,10 +16,9 @@ def run(cmd, descr, data=None, checks=None, region=None, log_error=True,
     """
     descr = _descr_str(descr, data, region)
     logger.debug(descr)
-    # TODO: Extract entity information from data input
-    cmd_id = diagnostics.start_cmd(descr, data, cmd)
+    cmd_id = diagnostics.start_cmd(cmd, descr, data)
     try:
-        logger_cl.debug(" ".join(cmd) if not isinstance(cmd, basestring) else cmd)
+        logger_cl.debug(" ".join(str(x) for x in cmd) if not isinstance(cmd, basestring) else cmd)
         _do_run(cmd, checks, log_stdout)
     except:
         diagnostics.end_cmd(cmd_id, False)
@@ -68,15 +67,17 @@ def _descr_str(descr, data, region):
     return descr
 
 def find_bash():
-    try:
-        which_bash = subprocess.check_output(["which", "bash"]).strip()
-    except subprocess.CalledProcessError:
-        which_bash = None
-    for test_bash in [which_bash, "/bin/bash", "/usr/bin/bash", "/usr/local/bin/bash"]:
+    for test_bash in [find_cmd("bash"), "/bin/bash", "/usr/bin/bash", "/usr/local/bin/bash"]:
         if test_bash and os.path.exists(test_bash):
             return test_bash
     raise IOError("Could not find bash in any standard location. Needed for unix pipes")
 
+def find_cmd(cmd):
+    try:
+        return subprocess.check_output(["which", cmd]).strip()
+    except subprocess.CalledProcessError:
+        return None
+
 def _normalize_cmd_args(cmd):
     """Normalize subprocess arguments to handle list commands, string and pipes.
     Piped commands set pipefail and require use of bash to help with debugging
@@ -89,7 +90,7 @@ def _normalize_cmd_args(cmd):
         else:
             return cmd, True, None
     else:
-        return cmd, False, None
+        return [str(x) for x in cmd], False, None
 
 def _do_run(cmd, checks, log_stdout=False):
     """Perform running and check results, raising errors for issues.
