@@ -18,31 +18,21 @@ from bcbio.utils import (file_exists, get_in)
 from bcbio.distributed.transaction import file_transaction
 from bcbio.log import logger
 from bcbio import bam
+import bcbio.pipeline.datadict as dd
 
 
 def _get_files(data):
     mapped = bam.mapped(data["work_bam"], data["config"])
     in_file = bam.sort(mapped, data["config"], order="queryname")
-    gtf_file = data["genome_resources"]["rnaseq"]["transcripts"]
-    work_dir = data["dirs"].get("work", "work")
+    gtf_file = dd.get_gtf_file(data)
+    work_dir = dd.get_work_dir(data)
     out_dir = os.path.join(work_dir, "htseq-count")
-    out_file = os.path.join(out_dir, data['rgnames']['sample']) + ".counts"
-    stats_file = os.path.join(out_dir, data['rgnames']['sample']) + ".stats"
+    sample_name = dd.get_sample_name(data)
+    out_file = os.path.join(out_dir, sample_name + ".counts")
+    stats_file = os.path.join(out_dir, sample_name + ".stats")
     return in_file, gtf_file, out_file, stats_file
 
 
-def is_countfile(in_file):
-    with open(in_file) as in_handle:
-        firstline = in_handle.next().split("\t")
-    if len(firstline) != 2:
-        return False
-    try:
-        int(firstline[1])
-    except ValueError:
-        return False
-    return True
-
-
 def invert_strand(iv):
     iv2 = iv.copy()
     if iv2.strand == "+":
@@ -57,19 +47,16 @@ def invert_strand(iv):
 class UnknownChrom(Exception):
     pass
 
-def _get_stranded_flag(config):
+def _get_stranded_flag(data):
     strand_flag = {"unstranded": "no",
                    "firststrand": "reverse",
                    "secondstrand": "yes"}
-    stranded = _get_strandedness(config)
+    stranded = dd.get_strandedness(data, "unstranded").lower()
     assert stranded in strand_flag, ("%s is not a valid strandedness value. "
                                      "Valid values are 'firststrand', 'secondstrand', "
                                      "and 'unstranded")
     return strand_flag[stranded]
 
-def _get_strandedness(config):
-    return get_in(config, ("algorithm", "strandedness"), "unstranded").lower()
-
 
 def htseq_count(data):
     """ adapted from Simon Anders htseq-count.py script
@@ -274,14 +261,15 @@ def htseq_count(data):
 
     return out_file
 
-def combine_count_files(files, out_file=None):
+def combine_count_files(files, out_file=None, ext=".fpkm"):
     """
     combine a set of count files into a single combined file
     """
+    assert all([file_exists(x) for x in files]), \
+        "Some count files in %s do not exist." % files
     for f in files:
         assert file_exists(f), "%s does not exist or is empty." % f
-        assert is_countfile(f), "%s does not seem to be a count file." % f
-    col_names = [os.path.basename(os.path.splitext(x)[0]) for x in files]
+    col_names = [os.path.basename(x.split(ext)[0]) for x in files]
     if not out_file:
         out_dir = os.path.join(os.path.dirname(files[0]))
         out_file = os.path.join(out_dir, "combined.counts")
