@@ -41,13 +41,28 @@ def annotate_nongatk_vcf(orig_file, bam_files, dbsnp_file, ref_file, config):
                 params = ["-T", "VariantAnnotator",
                           "-R", ref_file,
                           "--variant", orig_file,
-                          "--dbsnp", dbsnp_file,
                           "--out", tx_out_file,
                           "-L", orig_file]
+                if dbsnp_file:
+                    params += ["--dbsnp", dbsnp_file]
                 for bam_file in bam_files:
                     params += ["-I", bam_file]
                 for x in annotations:
                     params += ["-A", x]
+                if ("--allow_potentially_misencoded_quality_scores" not in params
+                      and "-allowPotentiallyMisencodedQuals" not in params):
+                    params += ["--allow_potentially_misencoded_quality_scores"]
+                # be less stringent about BAM and VCF files (esp. N in CIGAR for RNA-seq)
+                # start by removing existing -U or --unsafe opts
+                # (if another option is added to Gatk that starts with -U... this may create a bug)
+                unsafe_options = [x for x in params if x.startswith(("-U", "--unsafe"))]
+                for my_opt in unsafe_options:
+                    ind_to_rem = params.index(my_opt)
+                    # are the options given as separate strings or in one?
+                    if my_opt.strip() == "-U" or my_opt.strip() == "--unsafe":
+                        params.pop(ind_to_rem + 1)
+                    params.pop(ind_to_rem)
+                params.extend(["-U", "ALL"])
                 broad_runner = broad.runner_from_config(config)
                 broad_runner.run_gatk(params, memory_retry=True)
         vcfutils.bgzip_and_index(out_file, config)
