@@ -19,7 +19,7 @@ def clean_file(in_file, data, prefix=""):
         out_file = os.path.join(bedprep_dir, "%s%s" % (prefix, os.path.basename(in_file)))
         if not utils.file_exists(out_file):
             with file_transaction(out_file) as tx_out_file:
-                cmd = "grep -v ^track {in_file} | sort -k1,1 -k2,2n > {tx_out_file}"
+                cmd = "grep -v ^track {in_file} | grep -v ^browser | sort -k1,1 -k2,2n > {tx_out_file}"
                 do.run(cmd.format(**locals()), "Prepare cleaned BED file", data)
         vcfutils.bgzip_and_index(out_file, data["config"], remove_orig=False)
         return out_file
@@ -47,9 +47,12 @@ def merge_overlaps(in_file, data):
 
 def clean_inputs(data):
     """Clean BED input files to avoid overlapping segments that cause downstream issues.
+
+    Per-merges inputs to avoid needing to call multiple times during later parallel steps.
     """
-    data["config"]["algorithm"]["variant_regions"] = clean_file(
-        utils.get_in(data, ("config", "algorithm", "variant_regions")), data)
+    clean_vr = clean_file(utils.get_in(data, ("config", "algorithm", "variant_regions")), data)
+    merge_overlaps(clean_vr, data)
+    data["config"]["algorithm"]["variant_regions"] = clean_vr
     return data
 
 def combine(in_files, out_file, config):
