@@ -97,7 +97,7 @@ def _run_freebayes_caller(align_bams, items, ref_file, assoc_files,
                    "{compress_cmd} > {tx_out_file}")
             do.run(cmd.format(**locals()), "Genotyping with FreeBayes", {})
     ann_file = annotation.annotate_nongatk_vcf(out_file, align_bams,
-                                               assoc_files["dbsnp"],
+                                               assoc_files.get("dbsnp"),
                                                ref_file, config)
     return ann_file
 
@@ -150,7 +150,7 @@ def _run_freebayes_paired(align_bams, items, ref_file, assoc_files,
             do.run(cl.format(**locals()), "Genotyping paired variants with FreeBayes", {})
     fix_somatic_calls(out_file, config)
     ann_file = annotation.annotate_nongatk_vcf(out_file, align_bams,
-                                               assoc_files["dbsnp"], ref_file,
+                                               assoc_files.get("dbsnp"), ref_file,
                                                config)
     return ann_file
 
@@ -219,6 +219,9 @@ def fix_somatic_calls(in_file, config):
         # Add info to the header of the reader
         reader.infos["SOMATIC"] = somatic_info
         reader.filters["REJECT"] = reject_filter
+        for ext in [".gz", ".gz.tbi"]:
+            if os.path.exists(out_file + ext):
+                os.remove(out_file + ext)
         with file_transaction(out_file) as tx_out_file:
             with open(tx_out_file, "wb") as handle:
                 writer = vcf.VCFWriter(handle, template=reader)
